@@ -6,7 +6,7 @@ from eircode.proxy import Proxy
 class ProxyTest(TestCase):
 
     @skip('if no aws creds just skip')
-    def test_(self):
+    def test_proxy(self):
         proxy = Proxy(site='https://api.ipify.org')
 
         first_request = proxy.get('https://api.ipify.org')
